@@ -2,12 +2,10 @@ package MooseX::Getopt::Strict;
 BEGIN {
   $MooseX::Getopt::Strict::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MooseX::Getopt::Strict::VERSION = '0.37';
-}
-# ABSTRACT: only make options for attrs with the Getopt metaclass
-
+# ABSTRACT: only make options for attributes with the Getopt metaclass
+$MooseX::Getopt::Strict::VERSION = '0.62';
 use Moose::Role;
+use namespace::autoclean;
 
 with 'MooseX::Getopt';
 
@@ -19,19 +17,23 @@ around '_compute_getopt_attrs' => sub {
     } $class->$next(@args);
 };
 
-no Moose::Role;
-
 1;
 
-
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
+
+=for :stopwords Stevan Little Infinity Interactive, Inc
 
 =head1 NAME
 
-MooseX::Getopt::Strict - only make options for attrs with the Getopt metaclass
+MooseX::Getopt::Strict - only make options for attributes with the Getopt metaclass
+
+=head1 VERSION
+
+version 0.62
 
 =head1 DESCRIPTION
 
@@ -39,66 +41,15 @@ This is an stricter version of C<MooseX::Getopt> which only processes the
 attributes if they explicitly set as C<Getopt> attributes. All other attributes
 are ignored by the command line handler.
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
+=head1 AUTHOR
 
 Stevan Little <stevan@iinteractive.com>
 
-=item *
-
-Brandon L. Black <blblack@gmail.com>
-
-=item *
-
-Yuval Kogman <nothingmuch@woobling.org>
-
-=item *
-
-Ryan D Johnson <ryan@innerfence.com>
-
-=item *
-
-Drew Taylor <drew@drewtaylor.com>
-
-=item *
-
-Tomas Doran <bobtfish@bobtfish.net>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
-
-=item *
-
-Ævar Arnfjörð Bjarmason <avar@cpan.org>
-
-=item *
-
-Chris Prather <perigrin@cpan.org>
-
-=item *
-
-Karen Etheridge <ether@cpan.org>
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
